# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.style
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..container.x_index_replace import XIndexReplace as XIndexReplace_feed0dd7
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from .break_type import BreakType as BreakType_9b050ac0
    from .drop_cap_format import DropCapFormat as DropCapFormat_c95f0c4b
    from .graphic_location import GraphicLocation as GraphicLocation_e3ef0d30
    from .line_spacing import LineSpacing as LineSpacing_b1ad0b86
    from .paragraph_adjust import ParagraphAdjust as ParagraphAdjust_e42a0d3a
    from .tab_stop import TabStop as TabStop_860309f6
    from ..table.border_line import BorderLine as BorderLine_a3f80af6
    from ..table.shadow_format import ShadowFormat as ShadowFormat_bb840bdf
    from ..util.color import Color as Color_68e908c5

class ParagraphProperties(ABC):
    """
    Service Class

    describes the style of paragraphs.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API ParagraphProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html>`_
    """
    @property
    def ParaInteropGrabBag(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        Grab bag of paragraph properties, used as a string-any map for interim interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.2
        """
        ...
    @ParaInteropGrabBag.setter
    def ParaInteropGrabBag(self, value: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        ...
    @property
    def ParaTabStops(self) -> 'typing.Tuple[TabStop_860309f6, ...]':
        """
        specifies the positions and kinds of the tab stops within this paragraph.
        """
        ...
    @ParaTabStops.setter
    def ParaTabStops(self, value: 'typing.Tuple[TabStop_860309f6, ...]') -> None:
        ...
    @property
    def BorderDistance(self) -> int:
        """
        contains the distance from the border to the object.
        """
        ...
    @BorderDistance.setter
    def BorderDistance(self, value: int) -> None:
        ...
    @property
    def BottomBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the bottom border of the object.
        """
        ...
    @BottomBorder.setter
    def BottomBorder(self, value: 'BorderLine_a3f80af6') -> None:
        ...
    @property
    def BottomBorderDistance(self) -> int:
        """
        contains the distance from the bottom border to the object.
        """
        ...
    @BottomBorderDistance.setter
    def BottomBorderDistance(self, value: int) -> None:
        ...
    @property
    def BreakType(self) -> 'BreakType_9b050ac0':
        """
        determines the type of break that is applied at the beginning of the table.
        """
        ...
    @BreakType.setter
    def BreakType(self, value: 'BreakType_9b050ac0') -> None:
        ...
    @property
    def ContinueingPreviousSubTree(self) -> bool:
        """
        specifies that a child node of a parent node that is not counted is continuing the numbering of parent's previous node's sub tree.
        
        **since**
        
            OOo 3.0.1
        """
        ...
    @ContinueingPreviousSubTree.setter
    def ContinueingPreviousSubTree(self, value: bool) -> None:
        ...
    @property
    def DropCapCharStyleName(self) -> str:
        """
        specifies the character style name for drop caps.
        """
        ...
    @DropCapCharStyleName.setter
    def DropCapCharStyleName(self, value: str) -> None:
        ...
    @property
    def DropCapFormat(self) -> 'DropCapFormat_c95f0c4b':
        """
        specifies whether the first characters of the paragraph are displayed in capital letters and how they are formatted.
        """
        ...
    @DropCapFormat.setter
    def DropCapFormat(self, value: 'DropCapFormat_c95f0c4b') -> None:
        ...
    @property
    def DropCapWholeWord(self) -> bool:
        """
        specifies if the property DropCapFormat is applied to the whole first word.
        """
        ...
    @DropCapWholeWord.setter
    def DropCapWholeWord(self, value: bool) -> None:
        ...
    @property
    def LeftBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the left border of the object.
        """
        ...
    @LeftBorder.setter
    def LeftBorder(self, value: 'BorderLine_a3f80af6') -> None:
        ...
    @property
    def LeftBorderDistance(self) -> int:
        """
        contains the distance from the left border to the object.
        """
        ...
    @LeftBorderDistance.setter
    def LeftBorderDistance(self, value: int) -> None:
        ...
    @property
    def ListId(self) -> str:
        """
        specifies the id of the list to which the paragraph belongs
        """
        ...
    @ListId.setter
    def ListId(self, value: str) -> None:
        ...
    @property
    def ListLabelString(self) -> str:
        """
        allows reading the generated numbering list label.
        
        **since**
        
            OOo 3.0.1
        """
        ...
    @ListLabelString.setter
    def ListLabelString(self, value: str) -> None:
        ...
    @property
    def NumberingIsNumber(self) -> bool:
        """
        returns FALSE if the paragraph is part of a numbering, but has no numbering label.
        
        A paragraph is part of a numbering, if a style for a numbering is set - see NumberingStyleName.
        
        If the paragraph is not part of a numbering the property is void.
        """
        ...
    @NumberingIsNumber.setter
    def NumberingIsNumber(self, value: bool) -> None:
        ...
    @property
    def NumberingLevel(self) -> int:
        """
        specifies the numbering level of the paragraph.
        """
        ...
    @NumberingLevel.setter
    def NumberingLevel(self, value: int) -> None:
        ...
    @property
    def NumberingRules(self) -> 'XIndexReplace_feed0dd7':
        """
        contains the numbering rules applied to this paragraph.
        """
        ...
    @NumberingRules.setter
    def NumberingRules(self, value: 'XIndexReplace_feed0dd7') -> None:
        ...
    @property
    def NumberingStartValue(self) -> int:
        """
        specifies the start value for numbering if a new numbering starts at this paragraph.
        """
        ...
    @NumberingStartValue.setter
    def NumberingStartValue(self, value: int) -> None:
        ...
    @property
    def NumberingStyleName(self) -> str:
        """
        specifies the name of the style for the numbering.
        
        The name must be one of the names which are available via XStyleFamiliesSupplier.
        """
        ...
    @NumberingStyleName.setter
    def NumberingStyleName(self, value: str) -> None:
        ...
    @property
    def OutlineLevel(self) -> int:
        """
        specifies the outline level to which the paragraph belongs
        
        Value 0 indicates that the paragraph belongs to the body text.
        
        Values [1..10] indicates that the paragraph belongs to the corresponding outline level.
        
        **since**
        
            OOo 3.1
        """
        ...
    @OutlineLevel.setter
    def OutlineLevel(self, value: int) -> None:
        ...
    @property
    def PageDescName(self) -> str:
        """
        If this property is set, it creates a page break before the paragraph it belongs to and assigns the value as the name of the new page style sheet to use.
        """
        ...
    @PageDescName.setter
    def PageDescName(self, value: str) -> None:
        ...
    @property
    def PageNumberOffset(self) -> int:
        """
        If a page break property is set at a paragraph, this property contains the new value for the page number.
        """
        ...
    @PageNumberOffset.setter
    def PageNumberOffset(self, value: int) -> None:
        ...
    @property
    def PageStyleName(self) -> str:
        """
        contains the name of the current page style.
        """
        ...
    @PageStyleName.setter
    def PageStyleName(self, value: str) -> None:
        ...
    @property
    def ParaAdjust(self) -> 'ParagraphAdjust_e42a0d3a':
        """
        determines the adjustment of a paragraph.
        """
        ...
    @ParaAdjust.setter
    def ParaAdjust(self, value: 'ParagraphAdjust_e42a0d3a') -> None:
        ...
    @property
    def ParaBackColor(self) -> 'Color_68e908c5':
        """
        contains the paragraph background color.
        """
        ...
    @ParaBackColor.setter
    def ParaBackColor(self, value: 'Color_68e908c5') -> None:
        ...
    @property
    def ParaBackGraphic(self) -> 'XGraphic_a4da0afc':
        """
        contains the graphic for the background of a paragraph.
        
        **since**
        
            LibreOffice 6.1
        """
        ...
    @ParaBackGraphic.setter
    def ParaBackGraphic(self, value: 'XGraphic_a4da0afc') -> None:
        ...
    @property
    def ParaBackGraphicFilter(self) -> str:
        """
        contains the name of the graphic filter for the background graphic of a paragraph.
        """
        ...
    @ParaBackGraphicFilter.setter
    def ParaBackGraphicFilter(self, value: str) -> None:
        ...
    @property
    def ParaBackGraphicLocation(self) -> 'GraphicLocation_e3ef0d30':
        """
        contains the value for the position of a background graphic.
        """
        ...
    @ParaBackGraphicLocation.setter
    def ParaBackGraphicLocation(self, value: 'GraphicLocation_e3ef0d30') -> None:
        ...
    @property
    def ParaBackGraphicURL(self) -> str:
        """
        contains the value of a link for the background graphic of a paragraph.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the ParaBackGraphic property.
        """
        ...
    @ParaBackGraphicURL.setter
    def ParaBackGraphicURL(self, value: str) -> None:
        ...
    @property
    def ParaBackTransparent(self) -> bool:
        """
        This value is TRUE if the paragraph background color is set to transparent.
        """
        ...
    @ParaBackTransparent.setter
    def ParaBackTransparent(self, value: bool) -> None:
        ...
    @property
    def ParaBottomMargin(self) -> int:
        """
        determines the bottom margin of the paragraph in 100th mm.
        
        The distance between two paragraphs is specified by:
        
        The greater one is chosen.
        """
        ...
    @ParaBottomMargin.setter
    def ParaBottomMargin(self, value: int) -> None:
        ...
    @property
    def ParaContextMargin(self) -> bool:
        """
        determines if contextual spacing is used.
        
        If true, the top and bottom margins of the paragraph should not be applied when the previous and next paragraphs have the same style.
        
        **since**
        
            LibreOffice 3.6
        """
        ...
    @ParaContextMargin.setter
    def ParaContextMargin(self, value: bool) -> None:
        ...
    @property
    def ParaExpandSingleWord(self) -> bool:
        """
        determines if single words are stretched.
        
        It is only valid if ParagraphProperties.ParaAdjust and ParagraphProperties.ParaLastLineAdjust are also valid.
        """
        ...
    @ParaExpandSingleWord.setter
    def ParaExpandSingleWord(self, value: bool) -> None:
        ...
    @property
    def ParaFirstLineIndent(self) -> int:
        """
        specifies the indent for the first line.
        """
        ...
    @ParaFirstLineIndent.setter
    def ParaFirstLineIndent(self, value: int) -> None:
        ...
    @property
    def ParaHyphenationMaxHyphens(self) -> int:
        """
        specifies the maximum number of consecutive hyphens.
        """
        ...
    @ParaHyphenationMaxHyphens.setter
    def ParaHyphenationMaxHyphens(self, value: int) -> None:
        ...
    @property
    def ParaHyphenationMaxLeadingChars(self) -> int:
        """
        specifies the minimum number of characters to remain before the hyphen character (when hyphenation is applied).
        """
        ...
    @ParaHyphenationMaxLeadingChars.setter
    def ParaHyphenationMaxLeadingChars(self, value: int) -> None:
        ...
    @property
    def ParaHyphenationMaxTrailingChars(self) -> int:
        """
        specifies the minimum number of characters to remain after the hyphen character (when hyphenation is applied).
        """
        ...
    @ParaHyphenationMaxTrailingChars.setter
    def ParaHyphenationMaxTrailingChars(self, value: int) -> None:
        ...
    @property
    def ParaHyphenationMinWordLength(self) -> int:
        """
        specifies the minimum word length in characters, when hyphenation is applied.
        
        **since**
        
            LibreOffice 7.4
        """
        ...
    @ParaHyphenationMinWordLength.setter
    def ParaHyphenationMinWordLength(self, value: int) -> None:
        ...
    @property
    def ParaHyphenationNoCaps(self) -> bool:
        """
        Specifies whether words written in CAPS will be hyphenated.
        
        Setting to true will disable hyphenation of words written in CAPS for this paragraph.
        
        **since**
        
            LibreOffice 6.4
        """
        ...
    @ParaHyphenationNoCaps.setter
    def ParaHyphenationNoCaps(self, value: bool) -> None:
        ...
    @property
    def ParaHyphenationNoLastWord(self) -> bool:
        """
        Specifies whether last word of paragraph will be hyphenated.
        
        Setting to true will disable hyphenation of last word for this paragraph.
        
        **since**
        
            LibreOffice 7.4
        """
        ...
    @ParaHyphenationNoLastWord.setter
    def ParaHyphenationNoLastWord(self, value: bool) -> None:
        ...
    @property
    def ParaHyphenationZone(self) -> int:
        """
        specifies the hyphenation zone, i.e.
        
        allowed extra white space in the line before applying hyphenation.
        
        **since**
        
            LibreOffice 7.4
        """
        ...
    @ParaHyphenationZone.setter
    def ParaHyphenationZone(self, value: int) -> None:
        ...
    @property
    def ParaIsAutoFirstLineIndent(self) -> bool:
        """
        determines if the first line should be indented automatically.
        """
        ...
    @ParaIsAutoFirstLineIndent.setter
    def ParaIsAutoFirstLineIndent(self, value: bool) -> None:
        ...
    @property
    def ParaIsConnectBorder(self) -> bool:
        """
        the property determines if borders set at a paragraph are merged with the next paragraph.
        
        Borders are only merged if they are identical.
        """
        ...
    @ParaIsConnectBorder.setter
    def ParaIsConnectBorder(self, value: bool) -> None:
        ...
    @property
    def ParaIsHyphenation(self) -> bool:
        """
        specifies if automatic hyphenation is applied.
        """
        ...
    @ParaIsHyphenation.setter
    def ParaIsHyphenation(self, value: bool) -> None:
        ...
    @property
    def ParaIsNumberingRestart(self) -> bool:
        """
        determines if the numbering rules restart, counting at the current paragraph.
        """
        ...
    @ParaIsNumberingRestart.setter
    def ParaIsNumberingRestart(self, value: bool) -> None:
        ...
    @property
    def ParaKeepTogether(self) -> bool:
        """
        Setting this property to TRUE prevents page or column breaks between this and the following paragraph.
        
        This feature is useful for preventing title paragraphs to be the last line on a page or column.
        """
        ...
    @ParaKeepTogether.setter
    def ParaKeepTogether(self, value: bool) -> None:
        ...
    @property
    def ParaLastLineAdjust(self) -> int:
        """
        determines the adjustment of the last line.
        
        It is only valid if ParagraphProperties.ParaAdjust is set to ParagraphAdjust.BLOCK.
        """
        ...
    @ParaLastLineAdjust.setter
    def ParaLastLineAdjust(self, value: int) -> None:
        ...
    @property
    def ParaLeftMargin(self) -> int:
        """
        determines the left margin of the paragraph in 100th mm.
        """
        ...
    @ParaLeftMargin.setter
    def ParaLeftMargin(self, value: int) -> None:
        ...
    @property
    def ParaLineNumberCount(self) -> bool:
        """
        determines if the paragraph is included in the line numbering.
        """
        ...
    @ParaLineNumberCount.setter
    def ParaLineNumberCount(self, value: bool) -> None:
        ...
    @property
    def ParaLineNumberStartValue(self) -> int:
        """
        contains the start value for the line numbering.
        """
        ...
    @ParaLineNumberStartValue.setter
    def ParaLineNumberStartValue(self, value: int) -> None:
        ...
    @property
    def ParaLineSpacing(self) -> 'LineSpacing_b1ad0b86':
        """
        contains the type of the line spacing of a paragraph.
        """
        ...
    @ParaLineSpacing.setter
    def ParaLineSpacing(self, value: 'LineSpacing_b1ad0b86') -> None:
        ...
    @property
    def ParaOrphans(self) -> int:
        """
        specifies the minimum number of lines of the paragraph that have to be at bottom of a page if the paragraph is spread over more than one page.
        """
        ...
    @ParaOrphans.setter
    def ParaOrphans(self, value: int) -> None:
        ...
    @property
    def ParaRegisterModeActive(self) -> bool:
        """
        determines if the register mode is applied to a paragraph.
        
        Remark: Register mode is only used if the register mode property of the page style is switched on.
        """
        ...
    @ParaRegisterModeActive.setter
    def ParaRegisterModeActive(self, value: bool) -> None:
        ...
    @property
    def ParaRightMargin(self) -> int:
        """
        determines the right margin of the paragraph in 100th mm.
        """
        ...
    @ParaRightMargin.setter
    def ParaRightMargin(self, value: int) -> None:
        ...
    @property
    def ParaShadowFormat(self) -> 'ShadowFormat_bb840bdf':
        """
        determines the type, color, and size of the shadow.
        """
        ...
    @ParaShadowFormat.setter
    def ParaShadowFormat(self, value: 'ShadowFormat_bb840bdf') -> None:
        ...
    @property
    def ParaSplit(self) -> bool:
        """
        Setting this property to FALSE prevents the paragraph from getting split into two pages or columns.
        """
        ...
    @ParaSplit.setter
    def ParaSplit(self, value: bool) -> None:
        ...
    @property
    def ParaStyleName(self) -> str:
        """
        contains the name of the current paragraph style.
        """
        ...
    @ParaStyleName.setter
    def ParaStyleName(self, value: str) -> None:
        ...
    @property
    def ParaTopMargin(self) -> int:
        """
        determines the top margin of the paragraph in 100th mm.
        
        The distance between two paragraphs is specified by:
        
        The greater one is chosen.
        """
        ...
    @ParaTopMargin.setter
    def ParaTopMargin(self, value: int) -> None:
        ...
    @property
    def ParaUserDefinedAttributes(self) -> 'XNameContainer_cb90e47':
        """
        this property stores xml attributes.
        
        They will be saved to and restored from automatic styles inside xml files.
        """
        ...
    @ParaUserDefinedAttributes.setter
    def ParaUserDefinedAttributes(self, value: 'XNameContainer_cb90e47') -> None:
        ...
    @property
    def ParaVertAlignment(self) -> int:
        """
        specifies the vertical alignment of a paragraph.
        """
        ...
    @ParaVertAlignment.setter
    def ParaVertAlignment(self, value: int) -> None:
        ...
    @property
    def ParaWidows(self) -> int:
        """
        specifies the minimum number of lines of the paragraph that have to be at top of a page if the paragraph is spread over more than one page.
        """
        ...
    @ParaWidows.setter
    def ParaWidows(self, value: int) -> None:
        ...
    @property
    def RightBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the right border of the object.
        """
        ...
    @RightBorder.setter
    def RightBorder(self, value: 'BorderLine_a3f80af6') -> None:
        ...
    @property
    def RightBorderDistance(self) -> int:
        """
        contains the distance from the right border to the object.
        """
        ...
    @RightBorderDistance.setter
    def RightBorderDistance(self, value: int) -> None:
        ...
    @property
    def TopBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the top border of the object.
        """
        ...
    @TopBorder.setter
    def TopBorder(self, value: 'BorderLine_a3f80af6') -> None:
        ...
    @property
    def TopBorderDistance(self) -> int:
        """
        contains the distance from the top border to the object.
        """
        ...
    @TopBorderDistance.setter
    def TopBorderDistance(self, value: int) -> None:
        ...

